@@ -2,7 +2,7 @@
 
 #==============================================================================#
 # exerb.rb
-# $Id: exerb.rb,v 1.20 2002/12/27 06:34:45 yuya Exp $
+# $Id: exerb.rb,v 1.25 2003/01/23 05:44:28 yuya Exp $
 #==============================================================================#
 
 require 'getoptlong'
@@ -13,23 +13,29 @@ require 'exerb/config'
 # ExerbCommand Module
 module ExerbCommand
 
+  @@verbose = false
+
   def self.main
     options = parse_argv
 
     if options[:version]
       print_version
-      return
+      exit(1)
     end
 
     if options[:help] || ARGV.size < 1
       print_usage
-      return
+      exit(1)
     end
 
+    verbose("Exerb #{Exerb::VERSION}")
+
     rbcfile = ARGV[0]
     rbafile = make_filename(rbcfile, 'rba')
+    verbose("Recipe file = #{rbcfile}")
+    verbose("Archive file = #{rbafile}")
 
-    rbc = RecipeFile.new(rbcfile)
+    rbc = Exerb::RecipeFile.new(rbcfile)
     arc = rbc.archive
 
     corefile = options[:corefile]
@@ -37,12 +43,15 @@ module ExerbCommand
     corefile ||= rbc.corefile                        if rbc.corefile
     corefile ||= lookup_corefile(rbc.corename)       if rbc.corename
     corefile ||= lookup_corefile('cui')
+    verbose("Core file = #{corefile}")
 
     exefile = options[:output]
     exefile ||= rbc.output                           if rbc.output
     exefile ||= make_filename(rbcfile, 'exe')
+    verbose("Executable file = #{exefile}")
 
     if options[:debug]
+      verbose("Writing archive file...")
       File.open(rbafile, 'wb') { |file|
         arc.output(file)
       }
@@ -51,30 +60,33 @@ module ExerbCommand
     compress = options[:compress]
     compress ||= rbc.compress
 
+    verbose("Building archive...")
     arcbin  = Exerb::Binary::Archive.new(arc.pack, compress)
+    verbose("Loading core file...")
     corebin = Exerb::Binary::Core.new_from_file(corefile)
+    verbose("Building executable file...")
     exebin  = Exerb::Binary::Executable.new(arcbin, corebin)
     exebin.selfcheck
 
+    verbose("Writing executable file...")
     File.open(exefile, 'wb') { |file|
       exebin.output(file)
     }
+
+    verbose("ok")
   end
 
   def self.lookup_corefile(name)
     if Exerb::CORE.has_key?(name)
       return Exerb::CORE[name]
     else
-      raise "core name not found in exerb/config.rb : #{name}"
+      STDERR.puts "#{name} was not found in exerb/config.rb"
+      exit(1)
     end
   end
 
   def self.make_filename(filename, extension)
-    if /\.rbc$/i =~ filename
-      return filename.sub(/\.rbc$/i, '.' + extension)
-    else
-      return filename + '.' + extension
-    end
+    return filename.sub(/(\.rbc$|$)/, '.' + extension)
   end
 
   def self.parse_argv
@@ -84,6 +96,7 @@ module ExerbCommand
       ['--corefile', '-C', GetoptLong::REQUIRED_ARGUMENT],
       ['--output',   '-o', GetoptLong::REQUIRED_ARGUMENT],
       ['--compress', '-z', GetoptLong::NO_ARGUMENT],
+      ['--verbose',  '-v', GetoptLong::NO_ARGUMENT],
       ['--debug',    '-g', GetoptLong::NO_ARGUMENT],
       ['--version',  '-V', GetoptLong::NO_ARGUMENT],
       ['--help',     '-h', GetoptLong::NO_ARGUMENT]
@@ -95,11 +108,16 @@ module ExerbCommand
     }
 
     options[:compress] = !!options[:compress]
+    options[:verbose]  = !!options[:verbose]
     options[:debug]    = !!options[:debug]
     options[:version]  = !!options[:version]
     options[:help]     = !!options[:help]
 
+    @@verbose = options[:verbose]
+
     return options
+  rescue GetoptLong::InvalidOption
+    exit(1)
   end
 
   def self.print_usage
@@ -114,6 +132,7 @@ module ExerbCommand
     puts "  -C  --corefile  specifies exerb-core file."
     puts "  -o  --output    specifies output file."
     puts "  -z  --compress  compress the archive. (using Ruby/zlib)"
+    puts "  -v  --verbose   "
     puts "  -g  --debug     enable debug mode."
     puts "  -V  --version   display version."
     puts "  -h  --help      display this information."
@@ -130,53 +149,9 @@ module ExerbCommand
     puts "Exerb #{Exerb::VERSION}"
   end
 
-  #============================================================================#
-  # RecipeFile Class
-  class RecipeFile
-
-    def initialize(filepath)
-      @basedir = File.dirname(File.expand_path(filepath))
-      @archive = Exerb::Archive.new
-
-      @corename = nil
-      @corefile = nil
-      @output   = nil
-      @compress = false
-
-      File.open(filepath) { |file|
-        file.to_a
-      }.collect { |line|
-        line.strip
-      }.reject { |line|
-        line.empty? || /^#/ =~ line
-      }.collect { |line|
-        line.split(/\t+/)
-      }.each { |type, p1, p2|
-        case type.downcase
-        when 'kcode'    then @archive.set_kcode(p1)
-        when 'corename' then @corename = p1
-        when 'corefile' then @corefile = File.expand_path(p1, @basedir)
-        when 'output'   then @output   = File.expand_path(p1, @basedir)
-        when 'compress' then @compress = yesno(p1)
-        when 'script'   then @archive.add_script(p1, File.expand_path(p2 || p1, @basedir))
-        when 'library'  then @archive.add_dll(p1, File.expand_path(p2 || p1, @basedir))
-        else raise "syntax error : #{type}"
-        end
-      }
-    end
-
-    attr_reader :archive, :corename, :corefile, :output, :compress
-
-    def yesno(str)
-      case str
-      when 'yes' then true
-      when 'no'  then false
-      else raise 'yes or no'
-      end
-    end
-    private :yesno
-
-  end # RecipeFile
+  def self.verbose(msg)
+    puts(msg) if @@verbose
+  end
 
 end # ExerbCommand
 
