@@ -1,7 +1,7 @@
 
 #==============================================================================#
 # exerb/archive.rb
-# $Id: archive.rb,v 1.5 2002/09/20 09:12:12 yuya Exp $
+# $Id: archive.rb,v 1.10 2003/01/17 05:57:50 yuya Exp $
 #==============================================================================#
 
 #==============================================================================#
@@ -16,9 +16,8 @@ module Exerb
     # Initialize Method
 
     def initialize
-      @kcode  = 'none'
-      @script = []
-      @dll    = []
+      @kcode   = 'none'
+      @entries = []
     end
 
     #==========================================================================#
@@ -29,49 +28,45 @@ module Exerb
     end
 
     def add_script(name, filepath)
-      @script << Script.new(name, filepath)
+      @entries << EntryFile.new(name, ArchiveHeader::ENTRY_TYPE_SCRIPT, filepath)
     end
 
-    def add_dll(name, filepath)
-      @dll << DLL.new(name, filepath)
+    def add_library(name, filepath)
+      @entries << EntryFile.new(name, ArchiveHeader::ENTRY_TYPE_LIBRARY, filepath)
+    end
+
+    def add_binary(name, filepath)
+      @entries << EntryFile.new(name, ArchiveHeader::ENTRY_TYPE_BINARY, filepath)
     end
 
     def pack
-      name_table   = NameTable.new
-      script_table = ScriptTable.new
-      dll_table    = DLLTable.new
+      name_table  = NameTable.new
+      entry_table = EntryTable.new
 
-      @script.each { |script|
-        script_table.add(name_table.add(script.name), script.pack)
-      }
-
-      @dll.each { |dll|
-        dll_table.add(name_table.add(dll.name), dll.pack)
+      @entries.each { |entry|
+        entry_table.add(name_table.add(entry.name), entry.type, entry.pack)
       }
 
       packed_name_table   = name_table.pack
-      packed_script_table = script_table.pack
-      packed_dll_table    = dll_table.pack
+      packed_entry_table  = entry_table.pack
 
       archive_header = ArchiveHeader.new
       archive_header.signature        = 'RUBY'
       archive_header.time_date_stamp  = Time.now.to_i
       archive_header.offset_to_name   = ArchiveHeader.size
       archive_header.number_of_name   = name_table.size
-      archive_header.offset_to_script = ArchiveHeader.size + packed_name_table.size
-      archive_header.number_of_script = script_table.size
-      archive_header.offset_to_dll    = ArchiveHeader.size + packed_name_table.size + packed_script_table.size
-      archive_header.number_of_dll    = dll_table.size
+      archive_header.offset_to_entry  = ArchiveHeader.size + packed_name_table.size
+      archive_header.number_of_entry  = entry_table.size
 
       archive_header.options = case @kcode
                                when 'none' then ArchiveHeader::OPTIONS_KCODE_NONE
                                when 'euc'  then ArchiveHeader::OPTIONS_KCODE_EUC
                                when 'sjis' then ArchiveHeader::OPTIONS_KCODE_SJIS
                                when 'utf8' then ArchiveHeader::OPTIONS_KCODE_UTF8
-                               else raise 'invalid char-set'
+                               else raise 'Unknown char-set'
                                end
 
-      return archive_header.pack + packed_name_table + packed_script_table + packed_dll_table
+      return archive_header.pack + packed_name_table + packed_entry_table
     end
 
     def output(io)
@@ -85,21 +80,22 @@ module Exerb
     end
 
     #==========================================================================#
-    # Script Class
-    class Script
+    # EntryFile Class
+    class EntryFile
 
       #========================================================================#
       # Initialize Method
 
-      def initialize(name, filepath)
+      def initialize(name, type, filepath)
         @name     = name
+        @type     = type
         @filepath = filepath
       end
 
       #========================================================================#
       # Accessor
 
-      attr_reader :name, :filepath
+      attr_reader :name, :type, :filepath
 
       #========================================================================#
       # Instance Methods
@@ -108,33 +104,7 @@ module Exerb
         return File.open(filepath, 'rb') { |file| file.read }
       end
 
-    end # Script
-
-    #==========================================================================#
-    # DLL Class
-    class DLL
-
-      #========================================================================#
-      # Initialize Method
-
-      def initialize(name, filepath)
-        @name     = name
-        @filepath = filepath
-      end
-
-      #========================================================================#
-      # Accessor
-
-      attr_reader :name, :filepath
-
-      #========================================================================#
-      # Instance Methods
-
-      def pack
-        return File.open(filepath, 'rb') { |file| file.read }
-      end
-
-    end # DLL
+    end # EntryFile
 
   end # Archive
 
