@@ -1,7 +1,5 @@
-//{{NO_DEPENDENCIES}}
-// Microsoft Developer Studio generated include file.
-// Used by resource.rc
-//
+// $Id: resource.h,v 1.7 2003/02/10 06:04:15 yuya Exp $
+
 #define IDS_FAIL_CREATEFILE             1
 #define IDS_SCRIPT_NOT_FOUND            2
 #define IDS_FAIL_MODIFY_IMPORT_TABLE    3
@@ -16,14 +14,3 @@
 #define IDC_EDIT_CALLSTACK              1002
 #define IDC_EDIT_BACKTRACE              1003
 #define IDC_EDIT_TYPE                   1004
-
-// Next default values for new objects
-// 
-#ifdef APSTUDIO_INVOKED
-#ifndef APSTUDIO_READONLY_SYMBOLS
-#define _APS_NEXT_RESOURCE_VALUE        103
-#define _APS_NEXT_COMMAND_VALUE         40001
-#define _APS_NEXT_CONTROL_VALUE         1005
-#define _APS_NEXT_SYMED_VALUE           101
-#endif
-#endif
